@@ -8,6 +8,7 @@ from onnx2tf.utils.common_functions import (
     get_constant_or_variable,
     print_node_info,
     inverted_operation_enable_disable,
+    make_tf_node_info,
 )
 
 
@@ -95,3 +96,22 @@ def make_node(
             variance_epsilon=epsilon,
             name=graph_node.name,
         )
+
+    # Generation of Debug Info
+    tf_layers_dict[graph_node_output.name]['tf_node_info'] = \
+        make_tf_node_info(
+            node_info={
+                'tf_op_type': tf.nn.batch_normalization,
+                'tf_inputs': {
+                    'x': input_tensor,
+                    'mean': mean,
+                    'variance': variance,
+                    'offset': beta,
+                    'scale': gamma,
+                    'variance_epsilon': epsilon,
+                },
+                'tf_outputs': {
+                    'output': tf_layers_dict[graph_node_output.name]['tf_node'],
+                },
+            }
+        )
