@@ -8,6 +8,7 @@ from onnx2tf.utils.common_functions import (
     get_constant_or_variable,
     print_node_info,
     inverted_operation_enable_disable,
+    make_tf_node_info,
 )
 
 
@@ -222,3 +223,21 @@ def make_node(
                 name=graph_node.name,
             ),
         )
+
+    # Generation of Debug Info
+    tf_layers_dict[graph_node_output.name]['tf_node_info'] = \
+        make_tf_node_info(
+            node_info={
+                'tf_op_type': 'Pad',
+                'tf_inputs': {
+                    'x': input_tensor,
+                    'paddings': paddings,
+                    'constant_value': constant_value,
+                    'mode': mode,
+                    'tensor_rank': tensor_rank,
+                },
+                'tf_outputs': {
+                    'output': tf_layers_dict[graph_node_output.name]['tf_node'],
+                },
+            }
+        )
